<?php

namespace App\Http\Controllers;

use App\Models\Role;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class UserController extends Controller
{
    public function index(Request $request)
    {
    
        $users = User::all();
        return view('pages.users.index', compact('users'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
    
  
       $roles = Role::all();

        return view('pages.users.create', compact( 'roles'));

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            "name" => "required|string|min:3",
            "email" => "required|string",

        ]);

        $user_role = Auth::user()->role_id;

        if($user_role == 1){
           //Verifica se é super admin, caso sim cria um super usuario ou cria um gestor


           $requestData = $request->all();

           //Gera uma senha aleatória
           $password = Str::random(8);
   
           $user_request = [
               "name" => $requestData['name'],
               "email" => $requestData['email'],
               "password" => bcrypt($password),
               "role_id" =>  $requestData['role_id'],
              
           ];
   
           $user = User::create($user_request);
   
           session([
               'mensagem.sucesso'=>
               "Usuário criado com sucesso - Senha gerada: $password"]);
   
           // E-mail
        //    Mail::to($user)->send(new SenhaLoginMail($user, $password));
   
           //Antes de terminar enviar um email para o responsavel
           return redirect()->route('users.index');

         }
     
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $user = User::where('id', $id)->first();

        $roles = Role::all();


        return view('pages.users.show', compact('user', 'roles'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $user = User::where('id', $id)->first();
        $roles = Role::all();
   

        return view('pages.users.edit', compact('user', 'roles'));
    }


    public function update(Request $request)
    {
        $id = $request->id;

        $request->validate([
            'name' => 'required|string|max:100',
            'email' => 'required|email|max:100',
            'password' => 'nullable|string|max:100'
        ]);

        $updateUser = [
            "name" => $request->name,
            "email" => $request->email,
            "role_id" => $request->role_id,
        ];

        if (isset($request->password)) {
            $updateUser['password'] = Hash::make($request->password);
        }

        User::where("id", $id)->update($updateUser);

        return redirect()->route('users.index')
            ->with('success', 'Usuário atualizado com sucesso.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Http\Response
     */
    public function delete($id)
    {
        $user = User::find($id);
        $user->delete();

        return redirect()->route('users.index')
            ->with('success', 'Usuário excluído com sucesso.');
    }
}
